# Timezone Converter

Compare your local timezone with a foreign one.

`$ timezone-comparison tijuana`

![comparison between two timezones](https://git.io/JJKG6)

## Table of Contents

- [Motivation](#motivation)
- [Quickstart](#quickstart)
- [Available timezones](#available-timezones)
- [License](#license)

## Motivation

When working with people that are not in your local timezone, the available
resources are the usual webpages that only show _one_ hour at a time, which
is pretty inconvenient.

With this script you can quickly compare a full day of your timezone against
a foreign one.

## Quickstart

Install with pip

```bash
pip install timezone-comparison
```

Run

```bash
timezone-converter {timezone}
```

## Available timezones

`$ timezone-converter --list`

![list of available timezones](https://git.io/JJKGo)

## License

This project is licensed under the terms of the
[MIT](https://choosealicense.com/licenses/mit/) license.

<div align="right">
  <b><a href="#timezone-converter">↥ back to top</a></b>
</div>
